Current limitations
===================

.. _limitations-label:

Discrete sinusoid transform
---------------------------

xrft currently only supports discrete fourier transforms. We plan to implement
discrete sinusoid tranforms in the near future.
